==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/FormatRadialGaugeLabelEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FormatRadialGaugeLabelEventArgsDescription } from "./FormatRadialGaugeLabelEventArgsDescription";
/**
 * @hidden
 */
var FormatRadialGaugeLabelEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(FormatRadialGaugeLabelEventArgsDescriptionMetadata, _super);
    function FormatRadialGaugeLabelEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    FormatRadialGaugeLabelEventArgsDescriptionMetadata.b = function (a) {
        if (FormatRadialGaugeLabelEventArgsDescriptionMetadata.a == null) {
            FormatRadialGaugeLabelEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            FormatRadialGaugeLabelEventArgsDescriptionMetadata.c(FormatRadialGaugeLabelEventArgsDescriptionMetadata.a);
        }
        if (a.k(FormatRadialGaugeLabelEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ab(FormatRadialGaugeLabelEventArgsDescriptionMetadata.a);
    };
    FormatRadialGaugeLabelEventArgsDescriptionMetadata.c = function (a) {
    };
    FormatRadialGaugeLabelEventArgsDescriptionMetadata.d = function (a) {
        FormatRadialGaugeLabelEventArgsDescriptionMetadata.b(a);
        a.ad("FormatRadialGaugeLabelEventArgs", function () { return new FormatRadialGaugeLabelEventArgsDescription(); });
        a.ac("FormatRadialGaugeLabelEventArgs", FormatRadialGaugeLabelEventArgsDescriptionMetadata.a);
    };
    FormatRadialGaugeLabelEventArgsDescriptionMetadata.$t = markType(FormatRadialGaugeLabelEventArgsDescriptionMetadata, 'FormatRadialGaugeLabelEventArgsDescriptionMetadata');
    FormatRadialGaugeLabelEventArgsDescriptionMetadata.a = null;
    return FormatRadialGaugeLabelEventArgsDescriptionMetadata;
}(Base));
export { FormatRadialGaugeLabelEventArgsDescriptionMetadata };

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm5/lib/FormatRadialGaugeLabelEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FormatRadialGaugeLabelEventArgsDescription } from "./FormatRadialGaugeLabelEventArgsDescription";
/**
 * @hidden
 */
var FormatRadialGaugeLabelEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(FormatRadialGaugeLabelEventArgsDescriptionMetadata, _super);
    function FormatRadialGaugeLabelEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    FormatRadialGaugeLabelEventArgsDescriptionMetadata.b = function (a) {
        if (FormatRadialGaugeLabelEventArgsDescriptionMetadata.a == null) {
            FormatRadialGaugeLabelEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            FormatRadialGaugeLabelEventArgsDescriptionMetadata.c(FormatRadialGaugeLabelEventArgsDescriptionMetadata.a);
        }
        if (a.k(FormatRadialGaugeLabelEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ac(FormatRadialGaugeLabelEventArgsDescriptionMetadata.a);
    };
    FormatRadialGaugeLabelEventArgsDescriptionMetadata.c = function (a) {
    };
    FormatRadialGaugeLabelEventArgsDescriptionMetadata.d = function (a) {
        FormatRadialGaugeLabelEventArgsDescriptionMetadata.b(a);
        a.ae("FormatRadialGaugeLabelEventArgs", function () { return new FormatRadialGaugeLabelEventArgsDescription(); });
        a.ad("FormatRadialGaugeLabelEventArgs", FormatRadialGaugeLabelEventArgsDescriptionMetadata.a);
    };
    FormatRadialGaugeLabelEventArgsDescriptionMetadata.$t = markType(FormatRadialGaugeLabelEventArgsDescriptionMetadata, 'FormatRadialGaugeLabelEventArgsDescriptionMetadata');
    FormatRadialGaugeLabelEventArgsDescriptionMetadata.a = null;
    return FormatRadialGaugeLabelEventArgsDescriptionMetadata;
}(Base));
export { FormatRadialGaugeLabelEventArgsDescriptionMetadata };
